@@ -3,8 +3,6 @@
  *
  * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
  *
- * Contact: Aki Niemi <aki.niemi@nokia.com>
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * version 2 as published by the Free Software Foundation.
@@ -47,18 +45,28 @@
 
 struct sim_data {
 	GIsiClient *client;
+	gboolean registered;
 };
 
-/* Returns fake (static) file info for EFSPN */
-static gboolean efspn_file_info(gpointer user)
+struct file_info {
+	int fileid;
+	int length;
+	int structure;
+	int record_length;
+	unsigned char access[3];
+};
+
+/* Returns file info */
+static gboolean fake_file_info(gpointer user)
 {
 	struct isi_cb_data *cbd = user;
 	ofono_sim_file_info_cb_t cb = cbd->cb;
-	unsigned char access[3] = { 0x0f, 0xff, 0xff };
-
-	DBG("Returning dummy file_info for EFSPN");
-	CALLBACK_WITH_SUCCESS(cb, 17, 0, 0, access, cbd->data);
+	struct file_info const *fi = cbd->user;
 
+	DBG("Returning static file_info for %04x", fi->fileid);
+	CALLBACK_WITH_SUCCESS(cb,
+				fi->length, fi->structure, fi->record_length,
+				fi->access, cbd->data);
 	g_free(cbd);
 	return FALSE;
 }
@@ -66,39 +74,57 @@ static gboolean efspn_file_info(gpointer user)
 static void isi_read_file_info(struct ofono_sim *sim, int fileid,
 				ofono_sim_file_info_cb_t cb, void *data)
 {
-	if (fileid == SIM_EFSPN_FILEID) {
-		/* Fake response for EFSPN  */
-		struct isi_cb_data *cbd = isi_cb_data_new(NULL, cb, data);
-		g_idle_add(efspn_file_info, cbd);
-		return;
+	int i;
+	static struct file_info const info[] = {
+		{ SIM_EFSPN_FILEID, 17, 0, 0, { 0x0f, 0xff, 0xff } },
+		{ SIM_EF_ICCID_FILEID, 10, 0, 0, { 0x0f, 0xff, 0xff } },
+	};
+	int N = sizeof(info) / sizeof(info[0]);
+	struct isi_cb_data *cbd;
+
+	for (i = 0; i < N; i++) {
+		if (fileid == info[i].fileid) {
+			cbd = isi_cb_data_new((void *)&info[i], cb, data);
+			g_idle_add(fake_file_info, cbd);
+			return;
+		}
 	}
 
 	DBG("Not implemented (fileid = %04x)", fileid);
 	CALLBACK_WITH_FAILURE(cb, -1, -1, -1, NULL, data);
 }
 
-static bool spn_resp_cb(GIsiClient *client, const void *restrict data,
-			size_t len, uint16_t object, void *opaque)
+static gboolean spn_resp_cb(GIsiClient *client,
+				const void *restrict data, size_t len,
+				uint16_t object, void *opaque)
 {
 	const unsigned char *msg = data;
 	struct isi_cb_data *cbd = opaque;
 	ofono_sim_read_cb_t cb = cbd->cb;
-	unsigned char spn[17] = { 0xff };
+	unsigned char *spn = NULL;
+	unsigned char buffer[17];
 	int i;
 
 	if (!msg) {
 		DBG("ISI client error: %d", g_isi_client_error(client));
-		goto error;
+		goto done;
 	}
 
-	if (len < 39 || msg[0] != SIM_SERV_PROV_NAME_RESP)
-		 goto error;
+	if (len < 39 || msg[0] != SIM_SERV_PROV_NAME_RESP
+		|| msg[1] != SIM_ST_READ_SERV_PROV_NAME)
+		return FALSE;
 
-	if (msg[1] != SIM_ST_READ_SERV_PROV_NAME || msg[2] != SIM_SERV_OK)
-		goto error;
+	if (msg[2] != SIM_SERV_OK) {
+		DBG("Request failed: %s (0x%02X)",
+			sim_isi_cause_name(msg[2]), msg[2]);
+		goto done;
+	}
+
+	spn = buffer;
 
 	/* Set display condition bits */
 	spn[0] = ((msg[38] & 1) << 1) + (msg[37] & 1);
+
 	/* Dirty conversion from 16bit unicode to ascii */
 	for (i = 0; i < 16; i++) {
 		unsigned char c = msg[3 + i * 2 + 1];
@@ -108,50 +134,99 @@ static bool spn_resp_cb(GIsiClient *client, const void *restrict data,
 			c = '?';
 		spn[i + 1] = c;
 	}
-	DBG("SPN read successfully");
-	CALLBACK_WITH_SUCCESS(cb, spn, 17, cbd->data);
-	goto out;
 
-error:
-	DBG("Error reading SPN");
-	CALLBACK_WITH_FAILURE(cb, NULL, 0, cbd->data);
+done:
+	if (spn)
+		CALLBACK_WITH_SUCCESS(cb, spn, 17, cbd->data);
+	else
+		CALLBACK_WITH_FAILURE(cb, NULL, 0, cbd->data);
 
-out:
 	g_free(cbd);
-	return true;
+	return TRUE;
+}
+
+static gboolean isi_read_spn(struct ofono_sim *sim, struct isi_cb_data *cbd)
+{
+	struct sim_data *sd = ofono_sim_get_data(sim);
+
+	const unsigned char msg[] = {
+		SIM_SERV_PROV_NAME_REQ,
+		SIM_ST_READ_SERV_PROV_NAME,
+		0
+	};
+
+	return g_isi_request_make(sd->client, msg, sizeof(msg),
+					SIM_TIMEOUT, spn_resp_cb, cbd) != NULL;
+}
+
+static gboolean read_iccid_resp_cb(GIsiClient *client,
+					const void *restrict data, size_t len,
+					uint16_t object, void *user)
+{
+	struct isi_cb_data *cbd = user;
+	ofono_sim_read_cb_t cb = cbd->cb;
+	const unsigned char *msg = data;
+	const unsigned char *iccid = NULL;
+
+	if (!msg) {
+		DBG("ISI client error: %d", g_isi_client_error(client));
+		goto done;
+	}
+
+	if (len < 3 || msg[0] != SIM_READ_FIELD_RESP || msg[1] != ICC)
+		return FALSE;
+
+	if (msg[2] == SIM_SERV_OK && len >= 13)
+		iccid = msg + 3;
+	else
+		DBG("Error reading ICC ID");
+
+done:
+	if (iccid)
+		CALLBACK_WITH_SUCCESS(cb, iccid, 10, cbd->data);
+	else
+		CALLBACK_WITH_FAILURE(cb, NULL, 0, cbd->data);
+
+	g_free(cbd);
+	return TRUE;
+}
+
+static gboolean isi_read_iccid(struct ofono_sim *sim, struct isi_cb_data *cbd)
+{
+	struct sim_data *sd = ofono_sim_get_data(sim);
+	const unsigned char req[] = { SIM_READ_FIELD_REQ, ICC };
+
+	return g_isi_request_make(sd->client, req, sizeof(req), SIM_TIMEOUT,
+					read_iccid_resp_cb, cbd) != NULL;
 }
 
 static void isi_read_file_transparent(struct ofono_sim *sim, int fileid,
 					int start, int length,
 					ofono_sim_read_cb_t cb, void *data)
 {
-	struct isi_cb_data *cbd = NULL;
+	struct isi_cb_data *cbd = isi_cb_data_new(sim, cb, data);
 
-	if (fileid == SIM_EFSPN_FILEID) {
-		/* Hack support for EFSPN reading */
-		struct sim_data *simd = ofono_sim_get_data(sim);
-		const unsigned char msg[] = {
-			SIM_SERV_PROV_NAME_REQ,
-			SIM_ST_READ_SERV_PROV_NAME,
-			0
-		};
-		cbd = isi_cb_data_new(NULL, cb, data);
+	DBG("fileid = %04x", fileid);
 
-		if (!simd)
-			goto error;
+	switch (fileid) {
+	case SIM_EFSPN_FILEID:
 
-		cbd->user = sim;
-
-		if (g_isi_request_make(simd->client, msg, sizeof(msg),
-				       SIM_TIMEOUT, spn_resp_cb, cbd))
+		if (isi_read_spn(sim, cbd))
 			return;
+		break;
+
+	case SIM_EF_ICCID_FILEID:
+
+		if (isi_read_iccid(sim, cbd))
+			return;
+		break;
+
+	default:
+		DBG("Not implemented (fileid = %04x)", fileid);
 	}
-error:
-	if (cbd)
-		g_free(cbd);
 
-	DBG("Not implemented (fileid = %04x)", fileid);
 	CALLBACK_WITH_FAILURE(cb, NULL, 0, data);
+	g_free(cbd);
 }
 
 static void isi_read_file_linear(struct ofono_sim *sim, int fileid,
@@ -196,8 +271,9 @@ static void isi_write_file_cyclic(struct ofono_sim *sim, int fileid,
 	CALLBACK_WITH_FAILURE(cb, data);
 }
 
-static bool imsi_resp_cb(GIsiClient *client, const void *restrict data,
-				size_t len, uint16_t object, void *opaque)
+static gboolean imsi_resp_cb(GIsiClient *client,
+				const void *restrict data, size_t len,
+				uint16_t object, void *opaque)
 {
 	const unsigned char *msg = data;
 	struct isi_cb_data *cbd = opaque;
@@ -214,7 +290,7 @@ static bool imsi_resp_cb(GIsiClient *client, const void *restrict data,
 	}
 
 	if (len < 5 || msg[0] != SIM_IMSI_RESP_READ_IMSI)
-		 goto error;
+		goto error;
 
 	if (msg[1] != READ_IMSI || msg[2] != SIM_SERV_OK)
 		goto error;
@@ -247,7 +323,7 @@ error:
 
 out:
 	g_free(cbd);
-	return true;
+	return TRUE;
 }
 
 static void isi_read_imsi(struct ofono_sim *sim,
@@ -269,22 +345,97 @@ static void isi_read_imsi(struct ofono_sim *sim,
 		return;
 
 error:
-	if (cbd)
-		g_free(cbd);
-
 	CALLBACK_WITH_FAILURE(cb, NULL, data);
+	g_free(cbd);
 }
 
-static gboolean isi_sim_register(gpointer user)
+static void isi_sim_register(struct ofono_sim *sim)
 {
-	struct ofono_sim *sim = user;
 	struct sim_data *sd = ofono_sim_get_data(sim);
 
-	g_isi_client_set_debug(sd->client, sim_debug, NULL);
+	if (!sd->registered) {
+		sd->registered = TRUE;
+		ofono_sim_register(sim);
+		ofono_sim_inserted_notify(sim, TRUE);
+	}
+}
 
-	ofono_sim_register(sim);
+static gboolean read_hplmn_resp_cb(GIsiClient *client,
+					const void *restrict data, size_t len,
+					uint16_t object, void *opaque)
+{
+	const unsigned char *msg = data;
+	struct ofono_sim *sim = opaque;
 
-	return FALSE;
+	if (!msg) {
+		DBG("ISI client error: %d", g_isi_client_error(client));
+		return TRUE;
+	}
+
+	if (len < 3 || msg[0] != SIM_NETWORK_INFO_RESP || msg[1] != READ_HPLMN)
+		return FALSE;
+
+	if (msg[2] != SIM_SERV_NOTREADY)
+		isi_sim_register(sim);
+
+	return TRUE;
+}
+
+
+static void isi_read_hplmn(struct ofono_sim *sim)
+{
+	struct sim_data *sd = ofono_sim_get_data(sim);
+
+	const unsigned char req[] = {
+		SIM_NETWORK_INFO_REQ,
+		READ_HPLMN, 0
+	};
+
+	g_isi_request_make(sd->client, req, sizeof(req), SIM_TIMEOUT,
+				read_hplmn_resp_cb, sim);
+}
+
+static void sim_ind_cb(GIsiClient *client,
+			const void *restrict data, size_t len,
+			uint16_t object, void *opaque)
+{
+	struct ofono_sim *sim = opaque;
+	struct sim_data *sd = ofono_sim_get_data(sim);
+	const unsigned char *msg = data;
+
+	if (sd->registered)
+		return;
+
+	switch (msg[1]) {
+	case SIM_ST_PIN:
+		isi_sim_register(sim);
+		break;
+	case SIM_ST_INFO:
+		isi_read_hplmn(sim);
+		break;
+	}
+}
+
+static void sim_reachable_cb(GIsiClient *client, gboolean alive,
+				uint16_t object, void *opaque)
+{
+	struct ofono_sim *sim = opaque;
+
+	if (!alive) {
+		DBG("SIM client: %s", strerror(-g_isi_client_error(client)));
+		ofono_sim_remove(sim);
+		return;
+	}
+
+	DBG("%s (v.%03d.%03d) reachable",
+		pn_resource_name(g_isi_client_resource(client)),
+		g_isi_version_major(client),
+		g_isi_version_minor(client));
+
+	g_isi_subscribe(client, SIM_IND, sim_ind_cb, opaque);
+
+	/* Check if SIM is ready. */
+	isi_read_hplmn(sim);
 }
 
 static int isi_sim_probe(struct ofono_sim *sim, unsigned int vendor,
@@ -292,6 +443,7 @@ static int isi_sim_probe(struct ofono_sim *sim, unsigned int vendor,
 {
 	GIsiModem *idx = user;
 	struct sim_data *sd = g_try_new0(struct sim_data, 1);
+	const char *debug = getenv("OFONO_ISI_DEBUG");
 
 	if (!sd)
 		return -ENOMEM;
@@ -302,7 +454,10 @@ static int isi_sim_probe(struct ofono_sim *sim, unsigned int vendor,
 
 	ofono_sim_set_data(sim, sd);
 
-	g_idle_add(isi_sim_register, sim);
+	if (debug && (strcmp(debug, "all") == 0 || strcmp(debug, "sim") == 0))
+		g_isi_client_set_debug(sd->client, sim_debug, NULL);
+
+	g_isi_verify(sd->client, sim_reachable_cb, sim);
 
 	return 0;
 }
@@ -311,10 +466,12 @@ static void isi_sim_remove(struct ofono_sim *sim)
 {
 	struct sim_data *data = ofono_sim_get_data(sim);
 
-	if (data) {
-		g_isi_client_destroy(data->client);
-		g_free(data);
-	}
+	if (!data)
+		return;
+
+	ofono_sim_set_data(sim, NULL);
+	g_isi_client_destroy(data->client);
+	g_free(data);
 }
 
 static struct ofono_sim_driver driver = {
@@ -328,7 +485,7 @@ static struct ofono_sim_driver driver = {
 	.write_file_transparent	= isi_write_file_transparent,
 	.write_file_linear	= isi_write_file_linear,
 	.write_file_cyclic	= isi_write_file_cyclic,
-	.read_imsi		= isi_read_imsi
+	.read_imsi		= isi_read_imsi,
 };
 
 void isi_sim_init()
