@@ -40,9 +40,6 @@
 #include "storage.h"
 #include "idmap.h"
 
-#define DATA_CONNECTION_MANAGER_INTERFACE "org.ofono.DataConnectionManager"
-#define DATA_CONTEXT_INTERFACE "org.ofono.PrimaryDataContext"
-
 #define GPRS_FLAG_ATTACHING 0x1
 #define GPRS_FLAG_RECHECK 0x2
 
@@ -68,9 +65,6 @@ struct ofono_gprs {
 	ofono_bool_t roaming_allowed;
 	ofono_bool_t powered;
 	int status;
-	int location;
-	int cellid;
-	int technology;
 	int flags;
 	struct idmap *pid_map;
 	unsigned int last_context_id;
@@ -262,7 +256,7 @@ static void pri_context_signal_settings(struct pri_context *ctx)
 	DBusMessageIter iter;
 	const char *prop = "Settings";
 
-	signal = dbus_message_new_signal(path, DATA_CONTEXT_INTERFACE,
+	signal = dbus_message_new_signal(path, OFONO_DATA_CONTEXT_INTERFACE,
 						"PropertyChanged");
 
 	if (!signal)
@@ -441,7 +435,7 @@ static void pri_activate_callback(const struct ofono_error *error,
 
 	value = ctx->active;
 	ofono_dbus_signal_property_changed(conn, ctx->path,
-						DATA_CONTEXT_INTERFACE,
+						OFONO_DATA_CONTEXT_INTERFACE,
 						"Active", DBUS_TYPE_BOOLEAN,
 						&value);
 }
@@ -472,7 +466,7 @@ static void pri_deactivate_callback(const struct ofono_error *error, void *data)
 
 	value = ctx->active;
 	ofono_dbus_signal_property_changed(conn, ctx->path,
-						DATA_CONTEXT_INTERFACE,
+						OFONO_DATA_CONTEXT_INTERFACE,
 						"Active", DBUS_TYPE_BOOLEAN,
 						&value);
 }
@@ -502,7 +496,7 @@ static DBusMessage *pri_set_apn(struct pri_context *ctx, DBusConnection *conn,
 	g_dbus_send_reply(conn, msg, DBUS_TYPE_INVALID);
 
 	ofono_dbus_signal_property_changed(conn, ctx->path,
-						DATA_CONTEXT_INTERFACE,
+						OFONO_DATA_CONTEXT_INTERFACE,
 						"AccessPointName",
 						DBUS_TYPE_STRING, &apn);
 
@@ -532,7 +526,7 @@ static DBusMessage *pri_set_username(struct pri_context *ctx,
 	g_dbus_send_reply(conn, msg, DBUS_TYPE_INVALID);
 
 	ofono_dbus_signal_property_changed(conn, ctx->path,
-						DATA_CONTEXT_INTERFACE,
+						OFONO_DATA_CONTEXT_INTERFACE,
 						"Username",
 						DBUS_TYPE_STRING, &username);
 
@@ -562,7 +556,7 @@ static DBusMessage *pri_set_password(struct pri_context *ctx,
 	g_dbus_send_reply(conn, msg, DBUS_TYPE_INVALID);
 
 	ofono_dbus_signal_property_changed(conn, ctx->path,
-						DATA_CONTEXT_INTERFACE,
+						OFONO_DATA_CONTEXT_INTERFACE,
 						"Password",
 						DBUS_TYPE_STRING, &password);
 
@@ -593,8 +587,8 @@ static DBusMessage *pri_set_type(struct pri_context *ctx, DBusConnection *conn,
 	g_dbus_send_reply(conn, msg, DBUS_TYPE_INVALID);
 
 	ofono_dbus_signal_property_changed(conn, ctx->path,
-						DATA_CONTEXT_INTERFACE, "Type",
-						DBUS_TYPE_STRING, &type);
+						OFONO_DATA_CONTEXT_INTERFACE,
+						"Type", DBUS_TYPE_STRING, &type);
 
 	return NULL;
 }
@@ -620,8 +614,8 @@ static DBusMessage *pri_set_name(struct pri_context *ctx, DBusConnection *conn,
 	g_dbus_send_reply(conn, msg, DBUS_TYPE_INVALID);
 
 	ofono_dbus_signal_property_changed(conn, ctx->path,
-						DATA_CONTEXT_INTERFACE, "Name",
-						DBUS_TYPE_STRING, &name);
+						OFONO_DATA_CONTEXT_INTERFACE,
+						"Name", DBUS_TYPE_STRING, &name);
 
 	return NULL;
 }
@@ -801,7 +795,7 @@ static gboolean context_dbus_register(struct pri_context *ctx)
 
 	snprintf(path, sizeof(path), "%s/primarycontext%u", basepath, ctx->id);
 
-	if (!g_dbus_register_interface(conn, path, DATA_CONTEXT_INTERFACE,
+	if (!g_dbus_register_interface(conn, path, OFONO_DATA_CONTEXT_INTERFACE,
 					context_methods, context_signals,
 					NULL, ctx, pri_context_destroy)) {
 		ofono_error("Could not register PrimaryContext %s", path);
@@ -826,7 +820,7 @@ static gboolean context_dbus_unregister(struct pri_context *ctx)
 	idmap_put(ctx->gprs->pid_map, ctx->id);
 
 	return g_dbus_unregister_interface(conn, path,
-						DATA_CONTEXT_INTERFACE);
+						OFONO_DATA_CONTEXT_INTERFACE);
 }
 
 static char **gprs_contexts_path_list(GSList *context_list)
@@ -847,79 +841,6 @@ static char **gprs_contexts_path_list(GSList *context_list)
 	return objlist;
 }
 
-static void set_registration_status(struct ofono_gprs *gprs, int status)
-{
-	const char *str_status = registration_status_to_string(status);
-	const char *path = __ofono_atom_get_path(gprs->atom);
-	DBusConnection *conn = ofono_dbus_get_connection();
-
-	if (gprs->status == status)
-		return;
-
-	gprs->status = status;
-
-	ofono_dbus_signal_property_changed(conn, path,
-					DATA_CONNECTION_MANAGER_INTERFACE,
-					"Status", DBUS_TYPE_STRING,
-					&str_status);
-}
-
-static void set_registration_location(struct ofono_gprs *gprs,
-					int lac)
-{
-	DBusConnection *conn = ofono_dbus_get_connection();
-	const char *path = __ofono_atom_get_path(gprs->atom);
-	dbus_uint16_t dbus_lac = lac;
-
-	if (lac > 0xffff)
-		return;
-
-	gprs->location = lac;
-
-	if (gprs->location == -1)
-		return;
-
-	ofono_dbus_signal_property_changed(conn, path,
-					DATA_CONNECTION_MANAGER_INTERFACE,
-					"LocationAreaCode",
-					DBUS_TYPE_UINT16, &dbus_lac);
-}
-
-static void set_registration_cellid(struct ofono_gprs *gprs, int ci)
-{
-	DBusConnection *conn = ofono_dbus_get_connection();
-	const char *path = __ofono_atom_get_path(gprs->atom);
-	dbus_uint32_t dbus_ci = ci;
-
-	gprs->cellid = ci;
-
-	if (gprs->cellid == -1)
-		return;
-
-	ofono_dbus_signal_property_changed(conn, path,
-					DATA_CONNECTION_MANAGER_INTERFACE,
-					"CellId", DBUS_TYPE_UINT32,
-					&dbus_ci);
-}
-
-static void set_registration_technology(struct ofono_gprs *gprs,
-					int tech)
-{
-	const char *tech_str = registration_tech_to_string(tech);
-	DBusConnection *conn = ofono_dbus_get_connection();
-	const char *path = __ofono_atom_get_path(gprs->atom);
-
-	gprs->technology = tech;
-
-	if (gprs->technology == -1)
-		return;
-
-	ofono_dbus_signal_property_changed(conn, path,
-					DATA_CONNECTION_MANAGER_INTERFACE,
-					"Technology", DBUS_TYPE_STRING,
-					&tech_str);
-}
-
 static void gprs_attached_update(struct ofono_gprs *gprs)
 {
 	DBusConnection *conn = ofono_dbus_get_connection();
@@ -954,7 +875,7 @@ static void gprs_attached_update(struct ofono_gprs *gprs)
 
 			value = FALSE;
 			ofono_dbus_signal_property_changed(conn, ctx->path,
-						DATA_CONTEXT_INTERFACE,
+						OFONO_DATA_CONTEXT_INTERFACE,
 						"Active", DBUS_TYPE_BOOLEAN,
 						&value);
 		}
@@ -963,18 +884,17 @@ static void gprs_attached_update(struct ofono_gprs *gprs)
 	path = __ofono_atom_get_path(gprs->atom);
 	value = attached;
 	ofono_dbus_signal_property_changed(conn, path,
-				DATA_CONNECTION_MANAGER_INTERFACE,
+				OFONO_DATA_CONNECTION_MANAGER_INTERFACE,
 				"Attached", DBUS_TYPE_BOOLEAN, &value);
 }
 
 static void registration_status_cb(const struct ofono_error *error,
-					int status, int lac, int ci, int tech,
-					void *data)
+					int status, void *data)
 {
 	struct ofono_gprs *gprs = data;
 
 	if (error->type == OFONO_ERROR_TYPE_NO_ERROR)
-		ofono_gprs_status_notify(gprs, status, lac, ci, tech);
+		ofono_gprs_status_notify(gprs, status);
 
 	gprs->flags &= ~GPRS_FLAG_ATTACHING;
 
@@ -993,9 +913,9 @@ static void gprs_attach_callback(const struct ofono_error *error, void *data)
 	else
 		gprs->driver_attached = !gprs->driver_attached;
 
-	if (gprs->driver->registration_status) {
-		gprs->driver->registration_status(gprs, registration_status_cb,
-							gprs);
+	if (gprs->driver->attached_status) {
+		gprs->driver->attached_status(gprs, registration_status_cb,
+						gprs);
 		return;
 	}
 
@@ -1057,7 +977,6 @@ static DBusMessage *gprs_get_properties(DBusConnection *conn,
 	DBusMessageIter dict;
 	char **objpath_list;
 	dbus_bool_t value;
-	const char *status = registration_status_to_string(gprs->status);
 
 	reply = dbus_message_new_method_return(msg);
 	if (!reply)
@@ -1088,28 +1007,6 @@ static DBusMessage *gprs_get_properties(DBusConnection *conn,
 	value = gprs->powered;
 	ofono_dbus_dict_append(&dict, "Powered", DBUS_TYPE_BOOLEAN, &value);
 
-	ofono_dbus_dict_append(&dict, "Status", DBUS_TYPE_STRING, &status);
-
-	if (gprs->location != -1) {
-		dbus_uint16_t location = gprs->location;
-		ofono_dbus_dict_append(&dict, "LocationAreaCode",
-					DBUS_TYPE_UINT16, &location);
-	}
-
-	if (gprs->cellid != -1) {
-		dbus_uint32_t cellid = gprs->cellid;
-		ofono_dbus_dict_append(&dict, "CellId",
-					DBUS_TYPE_UINT32, &cellid);
-	}
-
-	if (gprs->technology != -1) {
-		const char *technology =
-			registration_tech_to_string(gprs->technology);
-
-		ofono_dbus_dict_append(&dict, "Technology", DBUS_TYPE_STRING,
-					&technology);
-	}
-
 	dbus_message_iter_close_container(&iter, &dict);
 
 	return reply;
@@ -1190,7 +1087,7 @@ static DBusMessage *gprs_set_property(DBusConnection *conn,
 
 	path = __ofono_atom_get_path(gprs->atom);
 	ofono_dbus_signal_property_changed(conn, path,
-					DATA_CONNECTION_MANAGER_INTERFACE,
+					OFONO_DATA_CONNECTION_MANAGER_INTERFACE,
 					property, DBUS_TYPE_BOOLEAN, &value);
 
 	return dbus_message_new_method_return(msg);
@@ -1268,7 +1165,7 @@ static DBusMessage *gprs_create_context(DBusConnection *conn,
 	if (objpath_list) {
 		path = __ofono_atom_get_path(gprs->atom);
 		ofono_dbus_signal_array_property_changed(conn, path,
-					DATA_CONNECTION_MANAGER_INTERFACE,
+					OFONO_DATA_CONNECTION_MANAGER_INTERFACE,
 					"PrimaryContexts",
 					DBUS_TYPE_OBJECT_PATH, &objpath_list);
 
@@ -1315,7 +1212,7 @@ static void gprs_deactivate_for_remove(const struct ofono_error *error,
 		DBusConnection *conn = ofono_dbus_get_connection();
 
 		ofono_dbus_signal_array_property_changed(conn, path,
-					DATA_CONNECTION_MANAGER_INTERFACE,
+					OFONO_DATA_CONNECTION_MANAGER_INTERFACE,
 					"PrimaryContexts",
 					DBUS_TYPE_OBJECT_PATH, &objpath_list);
 		g_strfreev(objpath_list);
@@ -1366,7 +1263,7 @@ static DBusMessage *gprs_remove_context(DBusConnection *conn,
 	if (objpath_list) {
 		path = __ofono_atom_get_path(gprs->atom);
 		ofono_dbus_signal_array_property_changed(conn, path,
-					DATA_CONNECTION_MANAGER_INTERFACE,
+					OFONO_DATA_CONNECTION_MANAGER_INTERFACE,
 					"PrimaryContexts",
 					DBUS_TYPE_OBJECT_PATH, &objpath_list);
 		g_strfreev(objpath_list);
@@ -1419,25 +1316,13 @@ void ofono_gprs_detached_notify(struct ofono_gprs *gprs)
 	 */
 }
 
-void ofono_gprs_status_notify(struct ofono_gprs *gprs,
-				int status, int lac, int ci, int tech)
+void ofono_gprs_status_notify(struct ofono_gprs *gprs, int status)
 {
 	/* If we are not attached and haven't tried to attach, ignore */
 	if (gprs->driver_attached == FALSE)
 		return;
 
-	if (gprs->status != status)
-		set_registration_status(gprs, status);
-
-	if (gprs->location != lac)
-		set_registration_location(gprs, lac);
-
-	if (gprs->cellid != ci)
-		set_registration_cellid(gprs, ci);
-
-	if (gprs->technology != tech)
-		set_registration_technology(gprs, tech);
-
+	gprs->status = status;
 	gprs_attached_update(gprs);
 }
 
@@ -1497,7 +1382,7 @@ void ofono_gprs_context_deactivated(struct ofono_gprs_context *gc,
 
 		value = FALSE;
 		ofono_dbus_signal_property_changed(conn, ctx->path,
-						DATA_CONTEXT_INTERFACE,
+						OFONO_DATA_CONTEXT_INTERFACE,
 						"Active", DBUS_TYPE_BOOLEAN,
 						&value);
 	}
@@ -1652,9 +1537,10 @@ static void gprs_unregister(struct ofono_atom *atom)
 		gprs->netreg = NULL;
 	}
 
-	ofono_modem_remove_interface(modem, DATA_CONNECTION_MANAGER_INTERFACE);
+	ofono_modem_remove_interface(modem,
+					OFONO_DATA_CONNECTION_MANAGER_INTERFACE);
 	g_dbus_unregister_interface(conn, path,
-					DATA_CONNECTION_MANAGER_INTERFACE);
+					OFONO_DATA_CONNECTION_MANAGER_INTERFACE);
 }
 
 static void gprs_remove(struct ofono_atom *atom)
@@ -1715,9 +1601,6 @@ struct ofono_gprs *ofono_gprs_create(struct ofono_modem *modem,
 
 	gprs->status = NETWORK_REGISTRATION_STATUS_UNKNOWN;
 	gprs->netreg_status = NETWORK_REGISTRATION_STATUS_UNKNOWN;
-	gprs->technology = -1;
-	gprs->cellid = -1;
-	gprs->location = -1;
 	gprs->pid_map = idmap_new(MAX_CONTEXTS);
 
 	return gprs;
@@ -1898,16 +1781,17 @@ void ofono_gprs_register(struct ofono_gprs *gprs)
 	struct ofono_atom *sim_atom;
 
 	if (!g_dbus_register_interface(conn, path,
-					DATA_CONNECTION_MANAGER_INTERFACE,
+					OFONO_DATA_CONNECTION_MANAGER_INTERFACE,
 					manager_methods, manager_signals, NULL,
 					gprs, NULL)) {
 		ofono_error("Could not create %s interface",
-				DATA_CONNECTION_MANAGER_INTERFACE);
+				OFONO_DATA_CONNECTION_MANAGER_INTERFACE);
 
 		return;
 	}
 
-	ofono_modem_add_interface(modem, DATA_CONNECTION_MANAGER_INTERFACE);
+	ofono_modem_add_interface(modem,
+				OFONO_DATA_CONNECTION_MANAGER_INTERFACE);
 
 	sim_atom = __ofono_modem_find_atom(modem, OFONO_ATOM_TYPE_SIM);
 
